@@ -222,7 +222,7 @@ def extract_tabular_statics(tabular_class: Union[type[TabularClassifier], type[T
             if not is_input_metatype(metatype, True):
                 raise ValidationError('invalid input metatype')
 
-        statics['input_metatypes'] = sorted(list(input_metatypes), key=lambda x: x.name)
+        statics['input_metatypes'] = sorted([x.name.lower() for x in input_metatypes])
 
         is_multioutput = tabular_class.is_multioutput()
         if not isinstance(is_multioutput, bool):
@@ -232,10 +232,10 @@ def extract_tabular_statics(tabular_class: Union[type[TabularClassifier], type[T
 
         if issubclass(tabular_class, TabularClassificationAlgo):
             target_metatype = tabular_class.target_metatype()
-            if not is_classification_metatype(target_metatype):
+            if not is_classification_metatype(target_metatype, True):
                 raise ValidationError('invalid classification metatype')
 
-            statics['target_metatype'] = target_metatype
+            statics['target_metatype'] = target_metatype.name.lower()
 
 
     if issubclass(tabular_class, TabularClassifier):
