@@ -2,14 +2,16 @@
 
 import numpy as np
 
+from typing import Any, Union
+
 from sklearn.metrics._scorer import SCORERS, get_scorer, _PredictScorer, _ProbaScorer, _ThresholdScorer
 from sklearn.utils.multiclass import type_of_target 
 
 from ..base.metric import Metric
-from ..base.types import Metatype, is_target_metatype
+from ..base.types import Metatype, PredictionMethod, is_target_metatype
 
 class SklearnMetric(Metric):
-    def __init__(self, scorer_name, metatypes, aggregation = 'mean'):
+    def __init__(self, scorer_name: str, metatypes: Union[Metatype, set[Metatype]], aggregation: str = 'mean'):
         """
         Invokes underlying score function.
 
@@ -20,11 +22,11 @@ class SklearnMetric(Metric):
         """
         scorer = get_scorer(scorer_name)
         if isinstance(scorer, _ProbaScorer):
-            prediction_method = 'predict_proba'
+            prediction_method = PredictionMethod.PREDICT_PROBA
         elif isinstance(scorer, _ThresholdScorer):
-            prediction_method = 'decision_function'
+            prediction_method = PredictionMethod.DECISION_FUNCTION
         else:
-            prediction_method = 'predict'
+            prediction_method = PredictionMethod.PREDICT
 
         if aggregation not in ('min','max','mean','median', None):
             raise ValueError('aggregation must be min, max, mean, median or None')
@@ -37,13 +39,13 @@ class SklearnMetric(Metric):
 
         self.pos_label = None
 
-    def to_dict(self):
+    def to_dict(self) -> dict:
         output = super().to_dict()
         if self.pos_label is not None:
             output['kwargs'] = dict(pos_label = self.pos_label)
         return output
 
-    def score(self, y, pred):
+    def score(self, y: Any, pred: Any) -> float:
         """
         Invokes underlying score function.
 
