@@ -17,11 +17,11 @@ def to_datetime(df):
     return df.apply(pd.to_datetime)
 
 def from_timestamp(df):
-    def float_to_timestamp(x):
+    def float_to_datetime(x):
         if pd.isnull(x):
             return x
         return datetime.datetime.fromtimestamp(x)
-    return df.astype(float).applymap(float_to_timestamp)
+    return df.astype(float).applymap(float_to_datetime)
 
 def to_text(df):
     return df.astype(str).mask(pd.isnull(df))
